==> apo-ws-client-6.00.10.2-sources.jar: fr/univlorraine/apowsclient/creationSE/EtapeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EtapeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EtapeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="licEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libEtp" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codCycle"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="temCouvertureSS" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temCouvertureAccTrv" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temOuvreDroitBourse" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codCursus" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codActionLOLF" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="nbMaxIAE" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *         &lt;element name="temTypOpi" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="listComposantesCGE" type="{EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauComposanteCGEDTO"/&gt;
 *         &lt;element name="listDroits" type="{EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauDroitDTO" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EtapeDTO", namespace = "EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codEtp",
    "licEtp",
    "libEtp",
    "codCycle",
    "temCouvertureSS",
    "temCouvertureAccTrv",
    "temOuvreDroitBourse",
    "codCursus",
    "codActionLOLF",
    "nbMaxIAE",
    "temTypOpi",
    "listComposantesCGE",
    "listDroits"
})
public class EtapeDTO {

    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String licEtp;
    @XmlElementRef(name = "libEtp", type = JAXBElement.class, required = false)
    protected JAXBElement<String> libEtp;
    @XmlElement(required = true, nillable = true)
    protected String codCycle;
    @XmlElementRef(name = "temCouvertureSS", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temCouvertureSS;
    @XmlElementRef(name = "temCouvertureAccTrv", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temCouvertureAccTrv;
    @XmlElementRef(name = "temOuvreDroitBourse", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temOuvreDroitBourse;
    @XmlElementRef(name = "codCursus", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codCursus;
    @XmlElementRef(name = "codActionLOLF", type = JAXBElement.class, required = false)
    protected JAXBElement<String> codActionLOLF;
    @XmlElementRef(name = "nbMaxIAE", type = JAXBElement.class, required = false)
    protected JAXBElement<String> nbMaxIAE;
    @XmlElementRef(name = "temTypOpi", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temTypOpi;
    @XmlElement(required = true)
    protected TableauComposanteCGEDTO listComposantesCGE;
    @XmlElementRef(name = "listDroits", type = JAXBElement.class, required = false)
    protected JAXBElement<TableauDroitDTO> listDroits;

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété licEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLicEtp() {
        return licEtp;
    }

    /**
     * Définit la valeur de la propriété licEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLicEtp(String value) {
        this.licEtp = value;
    }

    /**
     * Obtient la valeur de la propriété libEtp.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getLibEtp() {
        return libEtp;
    }

    /**
     * Définit la valeur de la propriété libEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setLibEtp(JAXBElement<String> value) {
        this.libEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codCycle.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCycle() {
        return codCycle;
    }

    /**
     * Définit la valeur de la propriété codCycle.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCycle(String value) {
        this.codCycle = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureSS.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemCouvertureSS() {
        return temCouvertureSS;
    }

    /**
     * Définit la valeur de la propriété temCouvertureSS.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemCouvertureSS(JAXBElement<String> value) {
        this.temCouvertureSS = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureAccTrv.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemCouvertureAccTrv() {
        return temCouvertureAccTrv;
    }

    /**
     * Définit la valeur de la propriété temCouvertureAccTrv.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemCouvertureAccTrv(JAXBElement<String> value) {
        this.temCouvertureAccTrv = value;
    }

    /**
     * Obtient la valeur de la propriété temOuvreDroitBourse.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemOuvreDroitBourse() {
        return temOuvreDroitBourse;
    }

    /**
     * Définit la valeur de la propriété temOuvreDroitBourse.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemOuvreDroitBourse(JAXBElement<String> value) {
        this.temOuvreDroitBourse = value;
    }

    /**
     * Obtient la valeur de la propriété codCursus.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodCursus() {
        return codCursus;
    }

    /**
     * Définit la valeur de la propriété codCursus.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodCursus(JAXBElement<String> value) {
        this.codCursus = value;
    }

    /**
     * Obtient la valeur de la propriété codActionLOLF.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getCodActionLOLF() {
        return codActionLOLF;
    }

    /**
     * Définit la valeur de la propriété codActionLOLF.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setCodActionLOLF(JAXBElement<String> value) {
        this.codActionLOLF = value;
    }

    /**
     * Obtient la valeur de la propriété nbMaxIAE.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getNbMaxIAE() {
        return nbMaxIAE;
    }

    /**
     * Définit la valeur de la propriété nbMaxIAE.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setNbMaxIAE(JAXBElement<String> value) {
        this.nbMaxIAE = value;
    }

    /**
     * Obtient la valeur de la propriété temTypOpi.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemTypOpi() {
        return temTypOpi;
    }

    /**
     * Définit la valeur de la propriété temTypOpi.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemTypOpi(JAXBElement<String> value) {
        this.temTypOpi = value;
    }

    /**
     * Obtient la valeur de la propriété listComposantesCGE.
     * 
     * @return
     *     possible object is
     *     {@link TableauComposanteCGEDTO }
     *     
     */
    public TableauComposanteCGEDTO getListComposantesCGE() {
        return listComposantesCGE;
    }

    /**
     * Définit la valeur de la propriété listComposantesCGE.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauComposanteCGEDTO }
     *     
     */
    public void setListComposantesCGE(TableauComposanteCGEDTO value) {
        this.listComposantesCGE = value;
    }

    /**
     * Obtient la valeur de la propriété listDroits.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link TableauDroitDTO }{@code >}
     *     
     */
    public JAXBElement<TableauDroitDTO> getListDroits() {
        return listDroits;
    }

    /**
     * Définit la valeur de la propriété listDroits.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link TableauDroitDTO }{@code >}
     *     
     */
    public void setListDroits(JAXBElement<TableauDroitDTO> value) {
        this.listDroits = value;
    }

}

==> apo-ws-client-6.00.50.2-sources.jar: fr/univlorraine/apowsclient/creationSE/EtapeDTO.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour EtapeDTO complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="EtapeDTO"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="licEtp" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="libEtp" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codCycle"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="temCouvertureSS" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temCouvertureAccTrv" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="temOuvreDroitBourse" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="codCursus" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="1"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="codActionLOLF" minOccurs="0"&gt;
 *           &lt;simpleType&gt;
 *             &lt;restriction base="{http://www.w3.org/2001/XMLSchema}string"&gt;
 *               &lt;maxLength value="2"/&gt;
 *             &lt;/restriction&gt;
 *           &lt;/simpleType&gt;
 *         &lt;/element&gt;
 *         &lt;element name="nbMaxIAE" type="{ElementPedagogiDTO3.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}nullableInt" minOccurs="0"/&gt;
 *         &lt;element name="temTypOpi" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="listComposantesCGE" type="{EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauComposanteCGEDTO"/&gt;
 *         &lt;element name="listDroits" type="{EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv}TableauDroitDTO" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "EtapeDTO", namespace = "EtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codEtp",
    "licEtp",
    "libEtp",
    "codCycle",
    "temCouvertureSS",
    "temCouvertureAccTrv",
    "temOuvreDroitBourse",
    "codCursus",
    "codActionLOLF",
    "nbMaxIAE",
    "temTypOpi",
    "listComposantesCGE",
    "listDroits"
})
public class EtapeDTO {

    @XmlElement(required = true, nillable = true)
    protected String codEtp;
    @XmlElement(required = true, nillable = true)
    protected String licEtp;
    @XmlElement(nillable = true)
    protected String libEtp;
    @XmlElement(required = true, nillable = true)
    protected String codCycle;
    @XmlElement(nillable = true)
    protected String temCouvertureSS;
    @XmlElement(nillable = true)
    protected String temCouvertureAccTrv;
    @XmlElement(nillable = true)
    protected String temOuvreDroitBourse;
    @XmlElement(nillable = true)
    protected String codCursus;
    @XmlElement(nillable = true)
    protected String codActionLOLF;
    @XmlElement(nillable = true)
    protected String nbMaxIAE;
    @XmlElement(nillable = true)
    protected String temTypOpi;
    @XmlElement(required = true)
    protected TableauComposanteCGEDTO listComposantesCGE;
    @XmlElement(nillable = true)
    protected TableauDroitDTO listDroits;

    /**
     * Obtient la valeur de la propriété codEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodEtp() {
        return codEtp;
    }

    /**
     * Définit la valeur de la propriété codEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodEtp(String value) {
        this.codEtp = value;
    }

    /**
     * Obtient la valeur de la propriété licEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLicEtp() {
        return licEtp;
    }

    /**
     * Définit la valeur de la propriété licEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLicEtp(String value) {
        this.licEtp = value;
    }

    /**
     * Obtient la valeur de la propriété libEtp.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getLibEtp() {
        return libEtp;
    }

    /**
     * Définit la valeur de la propriété libEtp.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setLibEtp(String value) {
        this.libEtp = value;
    }

    /**
     * Obtient la valeur de la propriété codCycle.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCycle() {
        return codCycle;
    }

    /**
     * Définit la valeur de la propriété codCycle.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCycle(String value) {
        this.codCycle = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureSS.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemCouvertureSS() {
        return temCouvertureSS;
    }

    /**
     * Définit la valeur de la propriété temCouvertureSS.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemCouvertureSS(String value) {
        this.temCouvertureSS = value;
    }

    /**
     * Obtient la valeur de la propriété temCouvertureAccTrv.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemCouvertureAccTrv() {
        return temCouvertureAccTrv;
    }

    /**
     * Définit la valeur de la propriété temCouvertureAccTrv.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemCouvertureAccTrv(String value) {
        this.temCouvertureAccTrv = value;
    }

    /**
     * Obtient la valeur de la propriété temOuvreDroitBourse.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemOuvreDroitBourse() {
        return temOuvreDroitBourse;
    }

    /**
     * Définit la valeur de la propriété temOuvreDroitBourse.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemOuvreDroitBourse(String value) {
        this.temOuvreDroitBourse = value;
    }

    /**
     * Obtient la valeur de la propriété codCursus.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCursus() {
        return codCursus;
    }

    /**
     * Définit la valeur de la propriété codCursus.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCursus(String value) {
        this.codCursus = value;
    }

    /**
     * Obtient la valeur de la propriété codActionLOLF.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodActionLOLF() {
        return codActionLOLF;
    }

    /**
     * Définit la valeur de la propriété codActionLOLF.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodActionLOLF(String value) {
        this.codActionLOLF = value;
    }

    /**
     * Obtient la valeur de la propriété nbMaxIAE.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNbMaxIAE() {
        return nbMaxIAE;
    }

    /**
     * Définit la valeur de la propriété nbMaxIAE.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNbMaxIAE(String value) {
        this.nbMaxIAE = value;
    }

    /**
     * Obtient la valeur de la propriété temTypOpi.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemTypOpi() {
        return temTypOpi;
    }

    /**
     * Définit la valeur de la propriété temTypOpi.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemTypOpi(String value) {
        this.temTypOpi = value;
    }

    /**
     * Obtient la valeur de la propriété listComposantesCGE.
     * 
     * @return
     *     possible object is
     *     {@link TableauComposanteCGEDTO }
     *     
     */
    public TableauComposanteCGEDTO getListComposantesCGE() {
        return listComposantesCGE;
    }

    /**
     * Définit la valeur de la propriété listComposantesCGE.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauComposanteCGEDTO }
     *     
     */
    public void setListComposantesCGE(TableauComposanteCGEDTO value) {
        this.listComposantesCGE = value;
    }

    /**
     * Obtient la valeur de la propriété listDroits.
     * 
     * @return
     *     possible object is
     *     {@link TableauDroitDTO }
     *     
     */
    public TableauDroitDTO getListDroits() {
        return listDroits;
    }

    /**
     * Définit la valeur de la propriété listDroits.
     * 
     * @param value
     *     allowed object is
     *     {@link TableauDroitDTO }
     *     
     */
    public void setListDroits(TableauDroitDTO value) {
        this.listDroits = value;
    }

}
